=====
aiofm
=====


Async file manager for Python

.. image:: https://img.shields.io/pypi/v/aiofm.svg
  :target: https://pypi.python.org/pypi/aiofm

.. image:: https://img.shields.io/travis/kamikaze/aiofm/master.svg?label=master%20build
  :target: https://travis-ci.org/kamikaze/aiofm

.. image:: https://coveralls.io/repos/github/kamikaze/aiofm/badge.svg?branch=master
  :target: https://coveralls.io/github/kamikaze/aiofm?branch=master

.. image:: https://codecov.io/gh/kamikaze/aiofm/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/kamikaze/aiofm

.. image:: https://readthedocs.org/projects/aiofm/badge/?version=latest
  :target: https://aiofm.readthedocs.io
  :alt: Documentation Status

.. image:: https://pyup.io/repos/github/kamikaze/aiofm/shield.svg
  :target: https://pyup.io/repos/github/kamikaze/aiofm/
  :alt: Updates

.. image:: https://pyup.io/repos/github/kamikaze/aiofm/python-3-shield.svg
  :target: https://pyup.io/repos/github/kamikaze/aiofm/
  :alt: Python 3

Description
===========

A longer description of your project goes here...


Note
====

This project has been set up using PyScaffold 3.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
